@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2024 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -220,7 +220,11 @@ namespace ipe {
       ENormal, ESplitHI, ESplitHO, ESplitVI, ESplitVO,
       EBlindsH, EBlindsV, EBoxI, EBoxO,
       EWipeLR, EWipeBT, EWipeRL, EWipeTB,
-      EDissolve, EGlitterLR, EGlitterTB, EGlitterD };
+      EDissolve, EGlitterLR, EGlitterTB, EGlitterD,
+      EFlyILR, EFlyOLR, EFlyITB, EFlyOTB, EPushLR, EPushTB,
+      ECoverLR, ECoverLB, EUncoverLR, EUncoverTB,
+      EFade
+    };
 
     Effect();
     void pageDictionary(Stream &stream) const;
@@ -264,15 +268,15 @@ namespace ipe {
     explicit Attribute(Fixed value);
     explicit Attribute(Color color);
     static Attribute Boolean(bool flag) { return Attribute(EEnum + flag); }
-    explicit Attribute(THorizontalAlignment align) { iName = EEnum + align +2; }
-    explicit Attribute(TVerticalAlignment align) { iName = EEnum + align + 5; }
-    explicit Attribute(TLineJoin join) { iName = EEnum + join + 9; }
-    explicit Attribute(TLineCap cap) { iName = EEnum + cap + 13; }
-    explicit Attribute(TFillRule rule) { iName = EEnum + rule + 17; }
-    explicit Attribute(TPinned pin) { iName = EEnum + pin + 20; }
-    explicit Attribute(TTransformations trans) { iName = EEnum + trans + 24; }
-    explicit Attribute(TPathMode pm) { iName = EEnum + pm + 27; }
-    explicit Attribute(TSplineType st) { iName = EEnum + st + 30; }
+    explicit Attribute(THorizontalAlignment align) { iName = EEnum + int(align) +2; }
+    explicit Attribute(TVerticalAlignment align) { iName = EEnum + int(align) + 5; }
+    explicit Attribute(TLineJoin join) { iName = EEnum + int(join) + 9; }
+    explicit Attribute(TLineCap cap) { iName = EEnum + int(cap) + 13; }
+    explicit Attribute(TFillRule rule) { iName = EEnum + int(rule) + 17; }
+    explicit Attribute(TPinned pin) { iName = EEnum + int(pin) + 20; }
+    explicit Attribute(TTransformations trans) { iName = EEnum + int(trans) + 24; }
+    explicit Attribute(TPathMode pm) { iName = EEnum + int(pm) + 27; }
+    explicit Attribute(TSplineType st) { iName = EEnum + int(st) + 30; }
 
     //! Is it symbolic?
     inline bool isSymbolic() const {
