@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2019 Otfried Cheong
+    Copyright (c) 1993-2024 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@
 #ifndef PDFLATEX_P_H
 #define PDFLATEX_P_H
 
+#include <list>
+
 #include "ipepage.h"
 #include "ipetext.h"
 #include "ipepdfparser.h"
@@ -46,7 +48,7 @@ namespace ipe {
 
   class Latex {
   public:
-    Latex(const Cascade *sheet, LatexType latexType);
+    Latex(const Cascade *sheet, LatexType latexType, bool sequentialText);
     ~Latex();
 
     int scanObject(const Object *obj);
@@ -65,13 +67,16 @@ namespace ipe {
     struct SText {
       const Text *iText;
       Attribute iSize;
+      Fixed iStretch;
+      String iSource;
     };
 
-    typedef std::list<SText> TextList;
-    typedef std::list<Text::XForm *> XFormList;
+    typedef std::vector<SText> TextList;
+    typedef std::vector<Text::XForm *> XFormList;
 
     const Cascade *iCascade;
     bool iXetex;
+    bool iSequentialText;
     LatexType iLatexType;
 
     PdfFile iPdf;
