@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2024 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -86,6 +86,9 @@ namespace ipe {
     virtual bool setAttribute(Property prop, Attribute value);
     virtual Attribute getAttribute(Property prop) const noexcept;
 
+    void setCustom(Attribute value);
+    Attribute getCustom() const noexcept;
+
     //! Save the object in XML format.
     virtual void saveAsXml(Stream &stream, String layer) const = 0;
 
@@ -136,9 +139,11 @@ namespace ipe {
     void saveAttributesAsXml(Stream &stream, String layer) const;
     static void checkSymbol(Kind kind, Attribute attr,
 			    const Cascade *sheet, AttributeSeq &seq);
+    Matrix effectiveMatrix(const Matrix & m, const Vector &pos = Vector::ZERO) const noexcept;
 
   protected:
     Matrix iMatrix;
+    Attribute iCustom;
     TPinned iPinned : 8;
     TTransformations iTransformations : 8;
   };
