@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2021 Otfried Cheong
+    Copyright (c) 1993-2024 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -62,14 +62,14 @@ prefs.autosave_interval = 600 -- 10 minutes
 -- Filename for autosaving
 -- can contain '%s' for the filename of the current file
 -- can use 'home' for the user's home directory
--- prefs.autosave_filename = home .. "/autosave.ipe"
--- On Windows, config.ipedrive gives you the root of the drive
--- where Ipe is installed.
--- prefs.autosave_filename = config.ipedrive .. "/autosave.ipe"
+-- on Windows, can use config.ipedrive for the root of the drive where Ipe is installed.
+-- if filename is relative, store in same directory as document itself,
+-- falling back on autosave_unnamed for documents that have not been saved yet
+prefs.autosave_filename = "%s.autosave.ipe"
 if config.platform == "win" then
-  prefs.autosave_filename = config.documents .. "\\%s.autosave"
+  prefs.autosave_unnamed = config.documents .. "\\autosave.ipe"
 else
-  prefs.autosave_filename = home .. "/%s.autosave"
+  prefs.autosave_unnamed = home .. "/autosave.ipe"
 end
 
 -- Should Ipe show the Developer menu
@@ -209,7 +209,19 @@ prefs.canvas_style = {
   -- color of the primary selection:
   primary_color = { r = 1.0, g = 0.0, b = 0.0 },
   -- color of the secondary selection:
-  secondary_color = { r = 1.0, g = 0.0, b = 1.0 },
+  secondary_color = { r = 0.8, g = 0.2, b = 0.8 },
+  -- color surrounding the selection
+  surround_color = { r = 1.0, g = 1.0, b = 0.0 },
+  -- width of the primary selection
+  primary_width = 3.0,
+  -- width of the secondary selection
+  secondary_width = 2.0,
+  -- width of the surrounding color for the selection
+  surround_width = 6.0,
+  -- color of the path attribute selector
+  path_view_color = { r = 1.0, g = 1.0, b = 0.5 },
+  -- color of grid lines
+  grid_line_color = { r = 0.3, g = 0.3, b = 0.3 },
   -- classic grid uses dots instead of lines
   classic_grid = false,
   -- line width of grid lines
@@ -280,8 +292,8 @@ prefs.normal_resolution = 72
 -- Maximum distance in pixels selecting/snapping
 prefs.select_distance = 36
 prefs.snap_distance = 16
--- When transforming objects, if currently select object is further than
--- this distance, the closest object is selected instead
+
+-- In the shredder and graph drawing tool, only select an object closer than this distance.
 prefs.close_distance = 48
 
 -- Zoom factors, minimal and maximal possible zoom
@@ -336,6 +348,8 @@ prefs.browser = "xdg-open %s"
 -- XFCE: exo-open
 -- Ubuntu/Debian: sensible-browser
 
+prefs.manual_url = "http://otfried.github.io/ipe"
+
 -- How to start onscreen keyboard
 if config.platform == "win" then
   prefs.keyboard = "tabtip.exe"
