@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (c) 1993-2020 Otfried Cheong
+    Copyright (c) 1993-2024 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ shortcuts = {
   behind = nil,
   duplicate = "D",
   select_all = "Ctrl+A",
-  join_paths = "Ctrl+J",
+  deselect_all = "Alt+Ctrl+A",
   pick_properties = "Q",
   apply_properties = "Ctrl+Q",
   insert_text_box = "F10",
@@ -119,6 +119,7 @@ shortcuts = {
   fullscreen = "F11",
   normal_size = "/",
   grid_visible = "F12",
+  pretty_display = "Ctrl+F12",
   zoom_in = "Ctrl+PgUp",
   zoom_out = "Ctrl+PgDown",
   fit_page = "\\",
