@@ -41,7 +41,7 @@ local f = io.open(texname, "r")
 text = f:read("*all")
 f:close()
 
-local mat = text:match("%%%%BeginIpePreamble(.*)%%%%EndIpePreamble")
+local mat = text:match("%%%%BeginIpePreamble(.-)%%%%EndIpePreamble")
 if not mat then
   io.stderr:write("No Ipe definitions found in '" .. texname .. "'\n")
   return
@@ -49,7 +49,9 @@ end
 
 local out = io.open("master-preamble.isy", "w")
 out:write('<ipestyle name="master-preamble">\n<preamble>\n')
-out:write(mat)
+for mat in text:gmatch("%%%%BeginIpePreamble(.-)%%%%EndIpePreamble") do
+    out:write(mat)
+end
 out:write("</preamble>\n</ipestyle>\n")
 out:close()
 
